* Chetan Gohil <chetan.gohil@psych.ox.ac.uk>
* Evan Roberts <evan.roberts@kellogg.ox.ac.uk>
* Rukuang Huang <rukuang.huang@jesus.ox.ac.uk>
* Usama Pervaiz <usama.pervaiz@ndcn.ox.ac.uk>
* Mark Woolrich <mark.woolrich@ohba.ox.ac.uk>

With contributions from former group members:

* Ryan Timms
* Alex Skates
